<?php
/*
 * Get array of contacts list from IEM
 */
function iemus_get_contact_list($iem_xml_path = '', $iem_xml_username = '', $iem_xml_token = ''){

    $resultData = null;

    //ignore if current user is not admin user
    if ( function_exists('is_super_admin') && !is_super_admin())
        return $resultData;

    if ($iem_xml_path && $iem_xml_username && $iem_xml_token ){

        $xml = "<xmlrequest>
		    <username>$iem_xml_username</username>
		    <usertoken>$iem_xml_token</usertoken>
		    <requesttype>user</requesttype>
		    <requestmethod>GetLists</requestmethod>
		    <details>
		    </details>
		</xmlrequest>";

        $ch = curl_init($iem_xml_path);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($ch, CURLOPT_POST, 1);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $xml);
        $result = @curl_exec($ch);
        if($result === false) {
            echo "Error to perform API request to your Interspire Email Marketer";
        } else {
            $xml_doc = simplexml_load_string($result);

            if ($xml_doc->status == 'SUCCESS') {
                $resultData = $xml_doc->data->item;
            } else {
                echo '<p style="background-color: #ffc;">Error while getting contacts list: ' . $xml_doc->errormessage . '</p><br/>';
            }
        }
    }
    return $resultData;
}

/*
 * Check for authentications
 */
function iemus_check_token($iem_xml_path = '', $iem_xml_username = '', $iem_xml_token = ''){

    $resultData = false;

    //ignore if current user is not admin user
    if ( function_exists('is_super_admin') && !is_super_admin())
        return $resultData;

    if ($iem_xml_path && $iem_xml_username && $iem_xml_token ){

        $xml = "<xmlrequest>
		    <username>$iem_xml_username</username>
		    <usertoken>$iem_xml_token</usertoken>
		    <requesttype>authentication</requesttype>
		    <requestmethod>xmlapitest</requestmethod>
		    <details>
		    </details>
		</xmlrequest>";

        $ch = curl_init($iem_xml_path);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($ch, CURLOPT_POST, 1);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $xml);
        $result = @curl_exec($ch);
        if($result === false) {
            echo "Error to perform API request to your Interspire Email Marketer";
        } else {
            $xml_doc = simplexml_load_string($result);

            if ($xml_doc->status == 'SUCCESS') {
                $resultData = $xml_doc->data; //1 = success, other is failed
            } else {
                echo '<p style="background-color: #fcc;">Error while checking for API authentication: ' . $xml_doc->errormessage . '</p><br/>';
            }
        }
    }

    return $resultData;
}

/*
 * Subscribe user to IEM list
 */
function iemus_subscribe($uid) {

    global $wpdb, $country_map;
    $user_email = $wpdb->get_var("SELECT user_email FROM " . $wpdb->users . " WHERE ID = '" . $uid . "'");
    if ( !empty( $user_email ) ) {

        $iem_xml_path = get_site_option('iem_xml_path');
        $iem_xml_username = get_site_option('iem_xml_username');
        $iem_xml_token = get_site_option('iem_xml_token');
        $iem_mapping = get_site_option('iem_mapping');

        $rolename = iemus_get_userrole_byid($uid);
        // $iem_list = iemus_get_list_by_role($rolename);
        $iem_list = $iem_mapping[$rolename][id];

        if ($iem_xml_path && $iem_xml_username && $iem_xml_token ){

            $xml = "
			<xmlrequest>
				<username>$iem_xml_username</username>
				<usertoken>$iem_xml_token</usertoken>
				<requesttype>subscribers</requesttype>
				<requestmethod>AddSubscriberToList</requestmethod>
				<details>
					<emailaddress>$user_email</emailaddress>
					<mailinglist>$iem_list</mailinglist>
					<format>html</format>
					<confirmed>yes</confirmed>
					";
            if(is_array($iem_mapping[$rolename][$iem_list]) && count($iem_mapping[$rolename][$iem_list])) {
                $xml .="<customfields>";
                foreach($iem_mapping[$rolename][$iem_list] as $k=>$v) {
                    //killer added for condition
                    if (!empty($v)){
                        $xml .= "<item><fieldid>$k</fieldid><value>".get_user_meta($uid, $v, true)."</value></item>";
                    }
                }
                $xml .="</customfields>";
            }
            $xml .="
				</details>
			</xmlrequest>";

            $ch = curl_init($iem_xml_path);
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
            curl_setopt($ch, CURLOPT_POST, 1);
            curl_setopt($ch, CURLOPT_POSTFIELDS, $xml);
            $result = @curl_exec($ch);
            if($result === false) {
                error_log("WP-IEM: Error performing request $user_email");
            }  else {
                $xml_doc = simplexml_load_string($result);
                if ($xml_doc->status != 'SUCCESS') {
                    error_log('WP-IEM: '.  $xml_doc->status . ' ' . $xml_doc->errormessage );
                }
            }
        }
    }
}

/*
 * get all custom fields of a list in iem
 */
function iemus_get_custom_fields($iem_xml_path = '', $iem_xml_username = '', $iem_xml_token = '', $listid = '')
{
    if (empty($iem_xml_path) || empty($iem_xml_username) || empty($iem_xml_token) || empty($listid))
        return null;

    $resultdata = null;

    $xml = "<xmlrequest>
            <username>$iem_xml_username</username>
            <usertoken>$iem_xml_token</usertoken>
            <requesttype>lists</requesttype>
            <requestmethod>GetCustomFields</requestmethod>
            <details>
                <listids>$listid</listids>
            </details>
            </xmlrequest>";

    $ch = curl_init($iem_xml_path);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
    curl_setopt($ch, CURLOPT_POST, 1);
    curl_setopt($ch, CURLOPT_POSTFIELDS, $xml);
    $result = @curl_exec($ch);
    if($result === false) {
        echo "Error while performing request to IEM API";
    }else {
        $xml_doc = simplexml_load_string($result);

        if ($xml_doc->status == 'SUCCESS') {
            $resultdata = $xml_doc;
        } else {
            echo 'IEM get custom fields is ' . $xml_doc->status . ':' . $xml_doc->errormessage . '<br/>';
        }
    }
    return $resultdata;
}

/*
 * Get a list of custom field's name in a list
 */
function iemus_get_custom_fields_array($iem_xml_path = '', $iem_xml_username = '', $iem_xml_token = '', $listid = '')
{
    if (empty($iem_xml_path) || empty($iem_xml_username) || empty($iem_xml_token) || empty($listid))
        return null;

    $resultdata = array();

    $cfdocs = iemus_get_custom_fields($iem_xml_path,$iem_xml_username,$iem_xml_token,$listid );

    if($cfdocs != null)
        foreach($cfdocs->data->item as $cf)
        {
            $field = array();
            $field['name']= $cf->name;
            $field['fieldid']= $cf->fieldid;
            $resultdata[] = $field;
        }

    return $resultdata;
}